#include <string.h>
#include <stdio.h>

#define N   (1 << 22)
#define T   (20)
int a[N],b[N];

extern void ca_copy(char *dest, char *src, int n);
extern void cp_copy(char *dest, char *src, int n);
extern void f_copy_(char *, char *, int * );

int main()
{
  int i;
  int sz = sizeof(a);
  for (i = 0; i < T; i++) { 
    ca_copy((char *) a,(char *) b,sz);
    cp_copy((char *)b,(char *)a,sz);
    f_copy_((char *)a,(char *)b,&sz);
    memcpy(b,a,sz);
  }
  printf("%d\n",a[0]);
}
