!--------------------------------------
! a fortran 90 implementation of memcpy
!--------------------------------------
subroutine f_copy(dest,src,n)
integer*8 n
integer*1 dest(n), src(n)
integer i
do i = 1, n
  dest(i) = src(i)
enddo
end
